@@ -20,6 +20,8 @@
 #include "rangefixvisitor.h"
 
 #include <QDebug>
+#include <QMutexLocker>
+
 #include "parserdebug.h"
 
 using namespace KDevelop;
@@ -33,31 +35,34 @@ QString PyUnicodeObjectToQString(PyObject* obj) {
     auto pyObjectCleanup = [](PyObject* o) { if (o) Py_DECREF(o); };
     const auto strOwner = std::unique_ptr<PyObject, decltype(pyObjectCleanup)>(PyObject_Str(obj), pyObjectCleanup);
     const auto str = strOwner.get();
-    if (PyUnicode_READY(str) < 0) {
-        qWarning("PyUnicode_READY(%p) returned false!", (void*)str);
-        return QString();
+
+    Py_ssize_t size;
+    const char *ptr = PyUnicode_AsUTF8AndSize(str, &size);
+    if (!ptr) {
+        qCWarning(KDEV_PYTHON_PARSER) << "failed to convert python string to unicode";
+        return {};
     }
-    const auto length = PyUnicode_GET_LENGTH(str);
-    switch(PyUnicode_KIND(str)) {
-        case PyUnicode_1BYTE_KIND:
-            return QString::fromLatin1((const char*)PyUnicode_1BYTE_DATA(str), length);
-        case PyUnicode_2BYTE_KIND:
-            return QString::fromUtf16(PyUnicode_2BYTE_DATA(str), length);
-        case PyUnicode_4BYTE_KIND:
-            return QString::fromUcs4(PyUnicode_4BYTE_DATA(str), length);
-    }
-    qCritical("PyUnicode_KIND(%p) returned an unexpected value, this should not happen!", (void*)str);
-    Q_UNREACHABLE();
+
+    return QString::fromUtf8(ptr, size);
 }
 
-struct PythonParser : private QMutexLocker
+struct PythonParser : private QMutexLocker<QMutex>
 {
     PyObject* m_parser_mod = nullptr;
     PyObject* m_parse_func = nullptr;
 
     PythonParser(QMutex& lock): QMutexLocker(&lock)
     {
+#if PYTHON_VERSION < QT_VERSION_CHECK(3, 12, 0)
         Py_InitializeEx(0);
+#else
+        PyConfig config;
+        PyConfig_InitPythonConfig(&config);
+        config.site_import = 0;
+        config.install_signal_handlers = 0;
+        Py_InitializeFromConfig(&config);
+#endif
+
         Q_ASSERT(Py_IsInitialized());
         m_parser_mod = PyImport_ImportModule("ast");
         Q_ASSERT(m_parser_mod); // parser import error
@@ -92,10 +97,12 @@ struct PythonParser : private QMutexLocker
 CodeAst::Ptr AstBuilder::parse(const QUrl& filename, QString &contents)
 {
     qCDebug(KDEV_PYTHON_PARSER) << " ====> AST     ====>     building abstract syntax tree for " << filename.path();
-    
+
+#if PYTHON_VERSION < QT_VERSION_CHECK(3, 12, 0)
     Py_NoSiteFlag = 1;
-    
-    contents.append('\n');
+#endif
+
+    contents.append(QLatin1Char('\n'));
     
     PythonParser py_parser(pyInitLock);
 
@@ -146,7 +153,7 @@ CodeAst::Ptr AstBuilder::parse(const QUrl& filename, QString &contents)
         int currentLine = 0;
         QString currentLineContents;
         QChar c;
-        QChar newline('\n');
+        QChar newline(QLatin1Char('\n'));
         int emptySince = 0; int emptySinceLine = 0; int emptyLinesSince = 0; int emptyLinesSinceLine = 0;
         unsigned short currentLineIndent = 0;
         bool atLineBeginning = true;
@@ -187,20 +194,20 @@ CodeAst::Ptr AstBuilder::parse(const QUrl& filename, QString &contents)
                 // if the last non-empty char before the error opens a new block, it's likely an "empty block" problem
                 // we can easily fix that by adding in a "pass" statement. However, we want to add that in the next line, if possible
                 // so context ranges for autocompletion stay intact.
-                if ( contents[emptySince] == QChar(':') ) {
+                if ( contents[emptySince] == QLatin1Char(':') ) {
                     qCDebug(KDEV_PYTHON_PARSER) << indents.length() << emptySinceLine + 1 << indents;
                     if ( indents.length() > emptySinceLine + 1 && indents.at(emptySinceLine) < indents.at(emptySinceLine + 1) ) {
                         qCDebug(KDEV_PYTHON_PARSER) << indents.at(emptySinceLine) << indents.at(emptySinceLine + 1);
-                        contents.insert(emptyLinesSince + 1 + indents.at(emptyLinesSinceLine), "\tpass#");
+                        contents.insert(emptyLinesSince + 1 + indents.at(emptyLinesSinceLine), QStringLiteral("\tpass#"));
                     }
                     else {
-                        contents.insert(emptySince + 1, "\tpass#");
+                        contents.insert(emptySince + 1, QStringLiteral("\tpass#"));
                     }
                 }
                 else if ( indents.length() >= currentLine && currentLine > 0 ) {
                     qCDebug(KDEV_PYTHON_PARSER) << indents << currentLine;
-                    contents[i+1+indents.at(currentLine - 1)] = QChar('#');
-                    contents.insert(i+1+indents.at(currentLine - 1), "pass");
+                    contents[i+1+indents.at(currentLine - 1)] = QLatin1Char('#');
+                    contents.insert(i+1+indents.at(currentLine - 1), QStringLiteral("pass"));
                 }
                 break;
             }
@@ -225,7 +232,7 @@ CodeAst::Ptr AstBuilder::parse(const QUrl& filename, QString &contents)
             for ( int i = currentLineBeginning; i < len; i++ ) {
                 c = contents.at(i);
                 qCDebug(KDEV_PYTHON_PARSER) << c;
-                if ( c == '\n' ) {
+                if ( c == QLatin1Char('\n') ) {
                     if ( currentIndent <= indentAtError && currentIndent != -1 ) {
                         qCDebug(KDEV_PYTHON_PARSER) << "Start of error code: " << currentLineBeginning;
                         qCDebug(KDEV_PYTHON_PARSER) << "End of error block (current position): " << currentLineBeginning_end;
@@ -234,7 +241,7 @@ CodeAst::Ptr AstBuilder::parse(const QUrl& filename, QString &contents)
 //                         contents.remove(currentLineBeginning, currentLineBeginning_end-currentLineBeginning);
                         break;
                     }
-                    contents.insert(currentLineContentBeginning - 1, "pass#");
+                    contents.insert(currentLineContentBeginning - 1, QStringLiteral("pass#"));
                     i += 5;
                     i = qMin(i, contents.length());
                     len = contents.length();
@@ -261,7 +268,7 @@ CodeAst::Ptr AstBuilder::parse(const QUrl& filename, QString &contents)
     qCDebug(KDEV_PYTHON_PARSER) << "Got syntax tree from python parser:" << kind;
 
     AstTransformer t;
-    t.run(syntaxtree, filename.fileName().replace(".py", ""));
+    t.run(syntaxtree, filename.fileName().replace(QStringLiteral(".py"), QString()));
     Py_DECREF(syntaxtree);
 
     RangeFixVisitor fixVisitor(contents);
